Learn R Programming

DyMEP (version 0.1.2)

asymptotic_prediction: DRC function: asymptotic_prediction

Description

DRC function: asymptotic_prediction

Usage

asymptotic_prediction(x, params)

Value

value with asymptotic response

Arguments

x

input variable

params

list of input parameter; Asym a numeric parameter representing the horizontal asymptote on the right side (very large values of input). ; lrc a numeric parameter representing the natural logarithm of the rate constant; c0 a numeric parameter representing the x for which the response is zero.

Examples

Run this code
asymptotic_prediction(5,list("Asym_value"=0.5,
                    "lrc_value"=0.2,
                      "c0_value"=4))
# visualization
asymptote <- lapply(seq(0, 10, 0.1),
asymptotic_prediction,
list("Asym_value"=0.5, "lrc_value"=0.2, "c0_value"=4))
plot(seq(0, 10, 0.1), asymptote)

Run the code above in your browser using DataLab