Learn R Programming

DyMEP (version 0.1.2)

available_crops_and_phases: available_crops_and_phases

Description

check what crops and corresponding phenology phases are available at the moment. Chose a crop (crop_abbrev), phenological phase from the output of this function further usage

Usage

available_crops_and_phases()

Arguments

Value

dataframe with available crops and phenology phases

Examples

Run this code
available_crops_and_phases()

Run the code above in your browser using DataLab