Learn R Programming

DyMEP (version 0.1.2)

available_environmental_covariates: available_environmental_covariates check what environmental covariates are implemented, use or alter prediction these abbreviations and the corresponding unit

Description

available_environmental_covariates check what environmental covariates are implemented, use or alter prediction these abbreviations and the corresponding unit

Usage

available_environmental_covariates()

Arguments

Value

dataframe with available environmental covariates

Examples

Run this code
available_environmental_covariates()

Run the code above in your browser using DataLab