dataframe with the best models selected for the given input arguments
Arguments
env_covariates
the environmental
covariates you have at hand; inputs as character strings naming the available
environmental covariate
pheno_phases
the phenological phases you are interested in. Input
as character string, available phenological phases do depend on the chosen
crop (use available_crops_and_phases())
crop_abbrev
the abbreviation of the wanted crop
skillscore_to_select
the skillscore according to which you want to
select (Default = "RMSE); available options: "RMSE", "MAE", "cor", "AIC" and
"SumLogLikelihood"
return_just_best
decide whether you want to get a list of all
potential options back, or just the best (default = TRUE)
output_list_for_prediction
boolean (TRUE/FALSE), if TRUE the output
of this function is a list which can directly be used for the
pheno_phase_prediction function as input (phase_covariate_list). Select
return_just_best also as TRUE if this output is wished