powered by
A function to cut the environmental data into the correct length
envpredutils.env_period_cutter( start_date, env_variables, env_data, max_period_length = 300 )
list with cut environmental covariates for the given period
start of the phase
name of the wanted variables
actual environmental data
in order to reduce computing time, a maximal amount of days will be considered (default = 300); if less data available, less days will be considered
envpredutils.env_period_cutter(Sys.Date(), c("tas"), list("tas"=data.frame("DATE"= seq(as.Date(Sys.Date()), (Sys.Date()+100),by="day"), "VALUE"= c(1:101))), 50)
Run the code above in your browser using DataLab