apply the prediction with glm model
envpredutils.pheno_phase_prediction_glm_model(
env_data_pheno_phase,
pheno_phase,
crop_abbrev,
model,
output_type = "dates"
)final output, either detailed (if output_type = "detailed_information") as list, or data.frame with dates if output_type = "dates"
environmental data required to predict the phase
phenological phase
abbreviation of the crop
the selected model to predict the wanted phenological phase
either "dates" or "detailed_information"; defines what output of the model they user wants to have as return, default is set to "dates". If a user wants to get the response parameters, curves, predictions and model thresholds, it should be chosen "detailed_information" output = "dates" will return a dataframe with the stages and according dates output = "detailed_information" will return a list with the dates, but also the corresponding dose response parameters and predictions